@@ -13,12 +13,10 @@
 #undef GNOME_PILOT_PATCHLEVEL
 #undef GNOME_PILOT_REVISION
 #undef GNOME_PILOT_VERSION
-#undef HAVE_MICO_ORB_RUN
 #undef PACKAGE
 #undef VERSION
 #undef USE_XOPEN_SOURCE
 #undef GNOME_ICONDIR
-#undef USING_OAF
 #undef WITH_USB_VISOR
 #undef WITH_IRDA
 #undef WITH_NETWORK
