@@ -23,6 +23,7 @@
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -103,8 +104,6 @@ typedef struct {
 static void show_error_dialog (PilotApplet *self, gchar*,...);
 static void show_warning_dialog (PilotApplet *self, gchar*,...);
 static void show_message_dialog (PilotApplet *self, gchar*,...);
-static void pause_cb (PanelApplet *widget, gpointer data);
-static void resume_cb (PanelApplet *widget, gpointer data);
 static void cancel_cb (GtkButton* button, gpointer whatever);
 
 static void save_properties (PilotApplet *self);
@@ -113,6 +112,10 @@ static void load_properties (PilotApplet *self);
 static void pilot_draw (PilotApplet*);
 
 static void pilot_execute_program (PilotApplet*, const gchar *);
+static gchar *pick_pilot (PilotApplet *self);
+
+static gboolean timeout (PilotApplet *self);
+
 #define GPILOTD_DRUID "gpilotd-control-applet --druid"
 #define GPILOTD_CAPPLET "gpilotd-control-applet"
 #define CONDUIT_CAPPLET "gpilotd-control-applet --cap-id=1"
@@ -150,7 +153,7 @@ gpilotd_connect_cb (GnomePilotClient *client,
 		applet->cancel_button        = glade_xml_get_widget (xml,"cancel_button");
 
 		gtk_signal_connect (GTK_OBJECT (applet->cancel_button),"clicked",
-				   GTK_SIGNAL_FUNC (cancel_cb),NULL);
+				   GTK_SIGNAL_FUNC (cancel_cb),applet);
 	} else {
 		gtk_text_buffer_place_cursor (applet->message_buffer,0);
 		gtk_text_buffer_set_text (applet->message_buffer, "", 0);
@@ -356,7 +359,7 @@ handle_client_error (PilotApplet *self)
 	}
 }
 
-void
+static void
 about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
 {
 	GtkWidget *about;
@@ -369,7 +372,7 @@ about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
 
 	about = gnome_about_new (_("gnome-pilot applet"), 
 				 VERSION,
-				 _("Copyright \xc2\xa9 2000-2003 Free Software Foundation, Inc."),
+				 _("Copyright 2000-2003 Free Software Foundation, Inc."),
 				 _("A dnd and gui monitor for gpilotd.\n"),
 				 (const gchar**)authors,
 				 NULL,
@@ -446,15 +449,147 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
 	gtk_widget_show_all (dialog);
 }
 
-void
+static void
 help_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
 	/* FIXME */
 	return;
 }
 
-void
-state_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+
+static void
+complete_restore (GnomePilotClient* client, const gchar *id, 
+		  unsigned long handle, gpointer user_data)
+{	
+	PilotApplet *applet = user_data;
+
+	gtk_widget_destroy (applet->operationDialogWindow);
+}
+
+static void
+cancel_restore (PilotApplet *self, GnomeDialog *w,gpointer data)
+{
+	g_message (_("cancelling %d"),GPOINTER_TO_INT (data));
+	gnome_pilot_client_remove_request (self->gpc,GPOINTER_TO_INT (data));  
+}
+
+
+static void
+restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+	int handle,i;
+	gchar *pilot_name;
+	gint pilot_id;
+	GladeXML *xml;
+	GtkWidget *dir_entry, *id_entry,*frame;
+	GtkWidget *device_menu, *menu_item,*menu;
+	GList *list;
+	gchar *buf;
+	restore_properties restore_props; 
+
+	
+	if (applet->curstate != WAITING) {
+		handle_client_error (applet);
+		return;
+	}
+	
+	if ((pilot_name=pick_pilot (applet)) == NULL) {
+		return;
+	}
+
+	if (gnome_pilot_client_get_pilot_base_dir_by_name (applet->gpc,pilot_name,&buf) == GPILOTD_OK) {
+		restore_props.backupdir = g_strdup_printf ("%s/backup/",buf);
+		g_free (buf);
+	} else {
+		handle_client_error (applet);
+		return;
+	}
+	if (gnome_pilot_client_get_pilot_id_by_name (applet->gpc,pilot_name,&pilot_id) != GPILOTD_OK) {
+		handle_client_error (applet);
+		return;
+	}
+
+	xml = glade_xml_new (applet->glade_file,"RestoreDialog",NULL);
+	applet->restoreDialog = glade_xml_get_widget (xml,"RestoreDialog");
+
+	dir_entry = glade_xml_get_widget (xml,"dir_entry");
+
+	gtk_entry_set_text (GTK_ENTRY (dir_entry),restore_props.backupdir);
+	g_free (restore_props.backupdir);
+	restore_props.backupdir=NULL;
+	/* FIXME: do we need to preserve the backupdir somewhere? */
+	
+	frame = glade_xml_get_widget (xml,"main_frame");
+	buf = g_strdup_printf (_("Restoring %s"), pilot_name);
+	gtk_frame_set_label (GTK_FRAME (frame), buf);
+	g_free (buf);
+	
+
+	id_entry =  glade_xml_get_widget (xml,"pilotid_entry");
+	
+	buf = g_strdup_printf ("%d",pilot_id);
+	gtk_entry_set_text (GTK_ENTRY (id_entry),buf);
+	g_free (buf);
+
+	applet->properties.cradles=NULL;
+	gnome_pilot_client_get_cradles (applet->gpc,&(applet->properties.cradles));
+	list = applet->properties.cradles;
+	
+	device_menu =  glade_xml_get_widget (xml,"device_menu");
+	menu =gtk_menu_new ();
+	
+	i=0;
+	while (list){
+		menu_item = gtk_menu_item_new_with_label ((gchar*)list->data);
+		gtk_widget_show (menu_item);
+/*
+		gtk_signal_connect (GTK_OBJECT (menu_item),"activate",
+				   GTK_SIGNAL_FUNC (activate_device),
+				   (gchar*)list->data);
+*/
+		gtk_menu_append (GTK_MENU (menu),menu_item);
+		list=list->next;
+		i++;
+	}
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (device_menu),menu);	
+	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_menu),FALSE);
+	else  gtk_widget_set_sensitive (GTK_WIDGET (device_menu),TRUE);
+	
+	if (gtk_dialog_run (GTK_DIALOG (applet->restoreDialog)) == GTK_RESPONSE_OK) {
+		int id;
+		
+		restore_props.backupdir = g_strdup(gtk_entry_get_text (GTK_ENTRY (dir_entry)));
+		gtk_widget_destroy (applet->restoreDialog);
+		if ( restore_props.backupdir == NULL || 
+		     strlen (restore_props.backupdir)==0) {
+			show_warning_dialog (applet, _("No directory to restore from."));
+			return;
+		}
+		
+		/* FIXME: how do we specify which device to restore on? */
+		id = gnome_pilot_client_connect__completed_request (applet->gpc, complete_restore, applet);
+		if (gnome_pilot_client_restore (applet->gpc,pilot_name,restore_props.backupdir,GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
+			applet->operationDialogWindow = 
+				gnome_message_box_new (_("Press synchronize on the cradle to restore\n" 
+							 " or cancel the operation."),
+						       GNOME_MESSAGE_BOX_GENERIC,
+						       GNOME_STOCK_BUTTON_CANCEL,
+						       NULL);
+			gnome_dialog_button_connect (GNOME_DIALOG (applet->operationDialogWindow),0,
+						     (GCallback) cancel_restore ,GINT_TO_POINTER (handle));
+			gnome_dialog_run_and_close (GNOME_DIALOG (applet->operationDialogWindow));
+		} else {
+			show_warning_dialog (applet,_("Restore request failed"));
+		}
+		gtk_signal_disconnect (applet->gpc, id);		
+	} else {
+		gtk_widget_destroy (applet->restoreDialog);
+	}	
+}
+
+static void
+state_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
 	PilotApplet *applet = user_data;
 	GnomePilotClient *gpc = applet->gpc;
@@ -476,8 +611,48 @@ state_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 	return;
 }
 
+
+static void
+restart_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+
+	if (applet->curstate == SYNCING) {
+		if ( gnome_dialog_run_and_close (GNOME_DIALOG (gnome_question_dialog (_("Pilot sync is currently in progress.\nAre you sure you want to restart daemon?"),NULL,NULL))) !=0 ) {
+			return;
+		}
+		if (applet->progressDialog!=NULL) {
+			gtk_widget_hide (applet->progressDialog);
+		}
+	}
+	applet->curstate = INITIALISING;
+	gnome_pilot_client_restart_daemon (applet->gpc);
+	gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet->applet),
+			      _("Trying to connect to the GnomePilot Daemon"), NULL);
+	applet->timeout_handler_id = gtk_timeout_add (1000,(GtkFunction)timeout,applet);
+
+	return;
+}
+
+static void
+log_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+{
+	PilotApplet *applet = user_data;
+	
+	if (applet->progressDialog != NULL) {
+		gtk_label_set_text (GTK_LABEL (applet->sync_label),"Last Sync Log");
+		gtk_widget_set_sensitive (applet->cancel_button,TRUE);
+		gtk_widget_show_all (applet->progressDialog);
+	} else {
+		show_message_dialog (applet, _("There's no last sync on record."));
+	}
+}
+
 static const BonoboUIVerb pilot_applet_menu_verbs [] = {
+	BONOBO_UI_VERB ("Restore", restore_cb),
 	BONOBO_UI_VERB ("State", state_cb),
+	BONOBO_UI_VERB ("Restart", restart_cb),
+	BONOBO_UI_VERB ("Log", log_cb),
 	BONOBO_UI_VERB ("Props", properties_cb),
 	BONOBO_UI_VERB ("Help", help_cb),
 	BONOBO_UI_UNSAFE_VERB ("About", about_cb),
@@ -491,9 +666,16 @@ install_popup_menu (PilotApplet *self, gboolean on_off)
 	char *menu_xml;
 	const char *menu_template = 
 		"<popup name=\"button3\">"
+		"<menuitem name=\"Restore\" verb=\"Restore\" _label=\"Restore...\""
+		"          pixtype=\"stock\" pixname=\"gtk-properties\"/>"
 		"<menuitem name=\"State\" verb=\"State\" _label=\"%s\""
 		"          pixtype=\"stock\" pixname=\"%s\"/>"
-		"<menuitem name=\"Props\" verb=\"Props\" _label=\"Properties...\""
+		"<menuitem name=\"Restart\" verb=\"Restart\" _label=\"Restart\""
+		"          pixtype=\"stock\" pixname=\"gtk-execute\"/>"
+		"<menuitem name=\"Log\" verb=\"Log\" _label=\"Last log...\""
+		"          pixtype=\"stock\" pixname=\"gtk-new\"/>"
+		"<separator/>"
+		"<menuitem name=\"Props\" verb=\"Props\" _label=\"Preferences...\""
 		"          pixtype=\"stock\" pixname=\"gtk-properties\"/>"
 		"<menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\""
 		"          pixtype=\"stock\" pixname=\"gtk-help\"/>"
@@ -700,6 +882,7 @@ timeout (PilotApplet *self)
 		break;
 	case SYNCING: 
 	case PAUSED:
+	default:
 		break;
 	}
 
@@ -788,12 +971,6 @@ save_properties (PilotApplet *self)
 	/* gnome_config_set_int ("text_limit",properties.text_limit); */
 }
 
-static void cancel_restore (PilotApplet *self, GnomeDialog *w,gpointer data) {
-	g_message (_("cancelling %d"),GPOINTER_TO_INT (data));
-	gnome_pilot_client_remove_request (self->gpc,GPOINTER_TO_INT (data));  
-}
-
-
 static void
 activate_pilot_menu (PilotApplet *self, GtkMenuItem *widget, gpointer data)
 {
@@ -847,163 +1024,6 @@ pick_pilot (PilotApplet *self)
 	return pilot;
 }
 
-static void
-restore_dialog (PilotApplet *self, gpointer data)
-{
-	int handle,i;
-	gchar *pilot_name;
-	gint pilot_id;
-	GladeXML *xml;
-	GtkWidget *dir_entry, *id_entry,*frame;
-	GtkWidget *device_menu, *menu_item,*menu;
-	GList *list;
-	gchar *buf;
-	restore_properties restore_props; 
-
-	
-	if (self->curstate!=WAITING) {
-		handle_client_error (self);
-		return;
-	}
-	
-	if ((pilot_name=pick_pilot (self)) == NULL) {
-		return;
-	}
-
-	if (gnome_pilot_client_get_pilot_base_dir_by_name (self->gpc,pilot_name,&buf) == GPILOTD_OK) {
-		restore_props.backupdir = g_strdup_printf ("%s/backup/",buf);
-		g_free (buf);
-	} else {
-		handle_client_error (self);
-		return;
-	}
-	if (gnome_pilot_client_get_pilot_id_by_name (self->gpc,pilot_name,&pilot_id) != GPILOTD_OK) {
-		handle_client_error (self);
-		return;
-	}
-
-	xml = glade_xml_new (self->glade_file,"RestoreDialog",NULL);
-	self->restoreDialog = glade_xml_get_widget (xml,"RestoreDialog");
-
-	dir_entry = glade_xml_get_widget (xml,"dir_entry");
-
-	gtk_entry_set_text (GTK_ENTRY (dir_entry),restore_props.backupdir);
-	g_free (restore_props.backupdir);
-	restore_props.backupdir=NULL;
-	/* FIXME: do we need to preserve the backupdir somewhere? */
-	
-	frame = glade_xml_get_widget (xml,"main_frame");
-	buf = g_strdup_printf (_("Restoring %s"), pilot_name);
-	gtk_frame_set_label (GTK_FRAME (frame), buf);
-	g_free (buf);
-	
-
-	id_entry =  glade_xml_get_widget (xml,"pilotid_entry");
-	
-	buf = g_strdup_printf ("%d",pilot_id);
-	gtk_entry_set_text (GTK_ENTRY (id_entry),buf);
-	g_free (buf);
-
-	self->properties.cradles=NULL;
-	gnome_pilot_client_get_cradles (self->gpc,&(self->properties.cradles));
-	list = self->properties.cradles;
-	
-	device_menu =  glade_xml_get_widget (xml,"device_menu");
-	menu =gtk_menu_new ();
-	
-	i=0;
-	while (list){
-		menu_item = gtk_menu_item_new_with_label ((gchar*)list->data);
-		gtk_widget_show (menu_item);
-/*
-		gtk_signal_connect (GTK_OBJECT (menu_item),"activate",
-				   GTK_SIGNAL_FUNC (activate_device),
-				   (gchar*)list->data);
-*/
-		gtk_menu_append (GTK_MENU (menu),menu_item);
-		list=list->next;
-		i++;
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (device_menu),menu);	
-	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_menu),FALSE);
-	else  gtk_widget_set_sensitive (GTK_WIDGET (device_menu),TRUE);
-	
-	if (gnome_dialog_run_and_close (GNOME_DIALOG (self->restoreDialog))==0) {
-
-		restore_props.backupdir = g_strdup(gtk_entry_get_text (GTK_ENTRY (dir_entry)));
-		if ( restore_props.backupdir == NULL || 
-		     strlen (restore_props.backupdir)==0) {
-			show_warning_dialog (self, _("No directory to restore from."));
-			return;
-		}
-		
-		/* FIXME: how do we specify which device to restore on? */
-		if (gnome_pilot_client_restore (self->gpc,pilot_name,restore_props.backupdir,GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
-			self->operationDialogWindow = 
-				gnome_message_box_new (_("Press synchronize on the cradle to restore\n" 
-							 " or cancel the operation."),
-						       GNOME_MESSAGE_BOX_GENERIC,
-						       GNOME_STOCK_BUTTON_CANCEL,
-						       NULL);
-			gnome_dialog_button_connect (GNOME_DIALOG (self->operationDialogWindow),0,
-						     (GCallback) cancel_restore ,GINT_TO_POINTER (handle));
-			gnome_dialog_run_and_close (GNOME_DIALOG (self->operationDialogWindow));
-		} else {
-			show_warning_dialog (self, _("Restore request failed"));
-		}
-	}
-}
-static void 
-properties_dialog (GtkWidget *w, gpointer data)
-{
-#ifdef FIXME
-	static GnomeHelpMenuEntry help_entry = {"gpilot-applet","properties"};
-
-	GtkWidget *button, *entry;
-	GladeXML *xml;
-
-	xml =glade_xml_new (self->glade_file,"PropertiesDialog");
-	pb=glade_xml_get_widget (xml,"PropertiesDialog");
-	
-	gtk_window_set_title (GTK_WINDOW (pb), _("GNOME PilotSync Properties"));
-
-
-	/* execute when clicked */
-
-	entry = glade_xml_get_widget (xml,"exec_entry");
-	gtk_entry_set_text (GTK_ENTRY (entry), properties.exec_when_clicked);
-	gtk_signal_connect_object (GTK_OBJECT (entry), "changed",
-				  GTK_SIGNAL_FUNC (gnome_property_box_changed),
-				  GTK_OBJECT (pb));
-	gtk_signal_connect (GTK_OBJECT (pb), "apply", 
-			   GTK_SIGNAL_FUNC (apply_exec_when_clicked_cb),entry);
-
-  
-	button = glade_xml_get_widget (xml,"notices_button");
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button),properties.popups);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			   GTK_SIGNAL_FUNC (toggle_notices_cb),
-			   NULL);
-
-
-/* 	gtk_signal_connect (GTK_OBJECT (pb),  */
-/* 			   "apply",  */
-/* 			   GTK_SIGNAL_FUNC (apply_properties_cb), */
-/* 			   NULL); */
-	gtk_signal_connect (GTK_OBJECT (pb),
-			   "destroy",
-			   GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			   pb);
-	gtk_signal_connect (GTK_OBJECT (pb),
-			   "help",
-			   GTK_SIGNAL_FUNC (gnome_help_pbox_display),
-			   &help_entry);
-
-	gtk_widget_show_all (pb);
-#endif
-	return;
-}
-
 static void
 pilot_execute_program (PilotApplet *self, const gchar *str)
 {
@@ -1038,28 +1058,6 @@ pilot_clicked_cb (GtkWidget *widget,
 	return TRUE; 
 }
 
-static void
-pilot_link_dialog (PilotApplet *self, GtkWidget *widget, gpointer data)
-{
-	if (data==NULL) {
-		pilot_execute_program (self, GPILOTD_CAPPLET);
-	} else {
-		pilot_execute_program (self, CONDUIT_CAPPLET);
-	}
-}
-
-static void
-lastlog_dialog (PilotApplet *self, GtkWidget *widget, gpointer data)
-{
-	if (self->progressDialog != NULL) {
-		/* gtk_label_set_text (GTK_LABEL (sync_label),"Last Sync Log"); */
-		gtk_widget_set_sensitive (self->cancel_button,TRUE);
-		gtk_widget_show_all (self->progressDialog);
-	} else {
-		show_message_dialog (self, _("There's no last sync on record."));
-	}
-}
-
 static void 
 cancel_cb (GtkButton* button,gpointer applet)
 {
@@ -1142,27 +1140,6 @@ applet_destroy (GtkWidget *applet, PilotApplet *self)
 	g_free (self);
 }
 
-static void
-restart_cb (PanelApplet *widget, gpointer data)
-{
-#ifdef FIXME
-	if ( curstate == SYNCING) {
-		if ( gnome_dialog_run_and_close (GNOME_DIALOG (gnome_question_dialog (_("Pilot sync is currently in progress.\nAre you sure you want to restart daemon?"),NULL,NULL))) !=0 ) {
-			return;
-		}
-		if (progressDialog!=NULL) {
-			gtk_widget_hide (progressDialog);
-		}
-	}
-	curstate = INITIALISING;
-	gnome_pilot_client_restart_daemon (gpc);
-	applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Trying to connect to "
-							  "the GnomePilot Daemon"));
-	timeout_handler_id = gtk_timeout_add (1000,timeout,pixmap);
-#endif
-	return;
-}
-
 static void
 create_pilot_widgets (GtkWidget *widget, PilotApplet *self) 
 { 
@@ -1211,46 +1188,10 @@ create_pilot_widgets (GtkWidget *widget, PilotApplet *self)
 	gtk_signal_connect (GTK_OBJECT (widget),"destroy", 
 			    GTK_SIGNAL_FUNC (applet_destroy),self); 
 
+	/* FIXME */
 	/* XXX change_orient */
 	/* XXX change_size */
-#if 0
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "restore", 
-					      GNOME_STOCK_PIXMAP_OPEN, 
-					      _("Restore..."), 
-					      restore_dialog, 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "restart", 
-					      GNOME_STOCK_PIXMAP_REFRESH, 
-					      _("Restart daemon"), 
-					      restart_cb, 
-					      NULL); 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "lastlog", 
-					      GNOME_STOCK_MENU_PREF, 
-					      _("Last sync log..."), 
-					      GTK_SIGNAL_FUNC (lastlog_dialog), 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "conduitprops", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Conduit Settings..."), 
-					      GTK_SIGNAL_FUNC (pilot_link_dialog), 
-					      GINT_TO_POINTER (1));	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "pilotlinkprops", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Pilot Link Settings..."), 
-					      GTK_SIGNAL_FUNC (pilot_link_dialog), 
-					      NULL);	 
-	applet_widget_register_stock_callback (APPLET_WIDGET (applet), 
-					      "properties", 
-					      GNOME_STOCK_MENU_PROP, 
-					      _("Properties..."), 
-					      GTK_SIGNAL_FUNC (properties_dialog), 
-					      NULL);	 
-#endif
+
 	/* Now set the dnd features */
 	gtk_drag_dest_set (GTK_WIDGET (self->pixmap), 
 			   GTK_DEST_DEFAULT_ALL, 
@@ -1266,28 +1207,6 @@ create_pilot_widgets (GtkWidget *widget, PilotApplet *self)
 	install_popup_menu (self, FALSE);
 }
 
-/* static GtkWidget * applet_start_new_applet (const gchar *goad_id, const char **params, int nparams) { */
-/* 	GtkWidget *pilot; */
-/* 	GtkWidget *applet; */
-  
-/* 	if (strcmp (goad_id, "gpilot-applet")) return NULL; */
-     
-/* 	applet = applet_widget_new (goad_id); */
-/* 	if (!applet) */
-/* 		g_error (_("Can't create applet!\n")); */
-  
-/* 	gtk_widget_realize (applet); */
-/* 	pilot = create_pilot_widget (applet); */
-/* 	gtk_widget_show_all (pilot); */
-
-
-/* 	applet_widget_add (APPLET_WIDGET (applet), pilot); */
-/* 	gtk_widget_show (applet); */
-  
-/* 	return applet; */
-/* } */
-
-
 static gboolean
 pilot_applet_fill (PanelApplet *applet)
 {
