@@ -81,7 +81,6 @@ struct _GnomePilotDruidPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
-	GtkWidget *pilot_sync_type;
 };
 
 static void class_init (GnomePilotDruidClass *klass);
@@ -94,6 +93,7 @@ static void fill_widgets (GnomePilotDruid *gpd);
 
 static gboolean gpd_delete_window (GtkWidget *widget,GdkEvent *event,gpointer user_data);
 static void gpd_canceled (GnomeDruid *druid, gpointer user_data);
+static void gpd_help (GnomeDruid *druid, gpointer user_data);
 
 static void gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data);
 static void gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data);
@@ -244,7 +244,6 @@ get_widgets (GnomePilotDruid *gpd)
 
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
-	priv->pilot_sync_type = GW ("sync_type_menu");
 	
 #undef GW
 
@@ -269,8 +268,7 @@ get_widgets (GnomePilotDruid *gpd)
 		&& priv->sync_label_vbox
 		&& priv->sync_label
 		&& priv->pilot_name
-		&& priv->pilot_basedir
-		&& priv->pilot_sync_type);
+		&& priv->pilot_basedir);
 }
 
 static void
@@ -292,7 +290,6 @@ map_widgets (GnomePilotDruid *gpd)
 	gtk_object_set_data (GTK_OBJECT (gpd), "pilotid", priv->pilot_id);
 	gtk_object_set_data (GTK_OBJECT (gpd), "pilotname", priv->pilot_name);
 	gtk_object_set_data (GTK_OBJECT (gpd), "basedir", priv->pilot_basedir);
-	gtk_object_set_data (GTK_OBJECT (gpd), "sync_menu", priv->pilot_sync_type);
 }
 
 static void 
@@ -308,21 +305,24 @@ init_widgets (GnomePilotDruid *gpd)
 
 	gtk_signal_connect (GTK_OBJECT (priv->druid), "cancel",
 			    GTK_SIGNAL_FUNC (gpd_canceled), gpd);
+	gtk_signal_connect (GTK_OBJECT (priv->druid), "help",
+			    GTK_SIGNAL_FUNC (gpd_help), gpd);
+
 
 	/* Page signals */
-	gtk_signal_connect (GTK_OBJECT (priv->page_cradle), "prepare",
-			    GTK_SIGNAL_FUNC (gpd_cradle_page_prepare), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_cradle), "prepare",
+				G_CALLBACK (gpd_cradle_page_prepare), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_sync), "prepare",
-			    GTK_SIGNAL_FUNC (gpd_sync_page_prepare), gpd);
-	gtk_signal_connect (GTK_OBJECT (priv->page_sync),"back",
-			   GTK_SIGNAL_FUNC (gpd_sync_page_back), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_sync), "prepare",
+				G_CALLBACK (gpd_sync_page_prepare), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_sync),"back",
+				G_CALLBACK (gpd_sync_page_back), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_pilot_two), "next",
-			    GTK_SIGNAL_FUNC (gpd_pilot_page_two_next), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_pilot_two), "next",
+				G_CALLBACK (gpd_pilot_page_two_next), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_finish), "finish",
-			    GTK_SIGNAL_FUNC (gpd_finish_page_finished), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_finish), "finish",
+				G_CALLBACK (gpd_finish_page_finished), gpd);
 
 	/* Other widget signals */
 	gtk_signal_connect (GTK_OBJECT (priv->device_name),"changed",
@@ -376,8 +376,6 @@ fill_widgets (GnomePilotDruid *gpd)
 
 	g_free (str);
 	g_free (str2);
-
-	fill_synctype_menu (GTK_OPTION_MENU (priv->pilot_sync_type), GnomePilotConduitSyncTypeNotSet);
 }
 
 gboolean
@@ -403,14 +401,16 @@ static gboolean
 cancel_dialog (GnomePilotDruid *gpd)
 {
 	GnomePilotDruidPrivate *priv;
-	gint btn;
+	GtkWidget *dlg;
 	
 	priv = gpd->priv;
-	
-	btn = yes_no_dialog (_("Setup did not complete and settings will not\n"
-				  "be saved. Are you sure you want to quit?"));
 
-	if (btn == 1) {
+	dlg = gtk_message_dialog_new (GTK_WINDOW (priv->druid_window), GTK_DIALOG_DESTROY_WITH_PARENT, 
+				      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+				      _("Setup did not complete and settings will not\n"
+					"be saved. Are you sure you want to quit?"));
+
+	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_YES) {
 		if (priv->handle > 0) {
 			gnome_pilot_client_remove_request (priv->gpc, priv->handle);
 			priv->handle =-1;
@@ -418,9 +418,15 @@ cancel_dialog (GnomePilotDruid *gpd)
 		save_config_and_restart (priv->gpc, priv->orig_state);
 		freePilotState (priv->state);
 		priv->state = dupPilotState (priv->orig_state);
+	
+		gtk_widget_destroy (dlg);
+	
+		return TRUE;
 	}
 
-	return btn ? TRUE : FALSE;
+	gtk_widget_destroy (dlg);
+
+	return FALSE;
 }
 
 static gboolean
@@ -458,6 +464,12 @@ gpd_canceled (GnomeDruid *druid, gpointer user_data)
 		gtk_main_quit ();
 }
 
+static void 
+gpd_help (GnomeDruid *druid, gpointer user_data)
+{
+	gnome_help_display_desktop (NULL, "gnome-pilot", "gnome-pilot.xml", "conftool-pilots", NULL);
+}
+
 static void
 gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 {
@@ -522,7 +534,7 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
         g_free (text);
 
 	if (priv->handle <= 0) {
-		error_dialog (_("Failed sending request to gpilotd"));
+		error_dialog (GTK_WINDOW (priv->druid_window), _("Failed sending request to gpilotd"));
 		return;
 	}
 
@@ -678,7 +690,7 @@ gpd_destroy (GtkObject *object)
 	priv = gpd->priv;
 
 	gtk_widget_destroy (priv->druid_window);
-	gtk_object_unref (GTK_OBJECT (priv->xml));
+	g_object_unref (priv->xml);
 
 	gtk_signal_disconnect_by_data (GTK_OBJECT (priv->gpc), object);
 
