@@ -562,7 +562,7 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 {
 	savePilotState (state);
 	/* FORCE the gpilotd to reread the settings */
-	gnome_pilot_client_restart_daemon (gpc);
+	gnome_pilot_client_reread_config (gpc);
 }
 
 gboolean
