@@ -29,6 +29,7 @@
 #include <pi-socket.h>
 #include <pi-dlp.h>
 #include <pi-sync.h>
+#include "gpmarshal.h"
 #include "gnome-pilot-conduit-sync-abs.h"
 #include "manager.h"
 
@@ -125,68 +126,6 @@ gnome_pilot_conduit_sync_abs_get_type (void)
 	return pilot_conduit_sync_abs_type;
 }
 
-/* We have a bunch of marshalling functions that we need to declare.
- * We do so here */
-typedef gint (*GtkSignal_INT__POINTER_POINTER) (GtkObject * object,
-						gpointer arg1,
-						gpointer arg2,
-						gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_POINTER (GtkObject * object,
-				  GtkSignalFunc func,
-				  gpointer func_data,
-				  GtkArg * args)
-{
-	GtkSignal_INT__POINTER_POINTER rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[2]);
-	rfunc = (GtkSignal_INT__POINTER_POINTER) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_POINTER (args[1]),
-				func_data);
-}
-
-typedef gint (*GtkSignal_INT__POINTER_INT) (GtkObject * object,
-					    gpointer arg1,
-					    gint arg2,
-					    gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_INT (GtkObject * object,
-			      GtkSignalFunc func,
-			      gpointer func_data,
-			      GtkArg * args)
-{
-	GtkSignal_INT__POINTER_INT rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[2]);
-	rfunc = (GtkSignal_INT__POINTER_INT) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_INT (args[1]),
-				func_data);
-}
-
-typedef gint (*GtkSignal_INT__POINTER_BOOL) (GtkObject * object,
-					     gpointer arg1,
-					     gboolean arg2,
-					     gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_BOOL (GtkObject * object,
-			      GtkSignalFunc func,
-			      gpointer func_data,
-			      GtkArg * args)
-{
-	GtkSignal_INT__POINTER_INT rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[2]);
-	rfunc = (GtkSignal_INT__POINTER_INT) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_BOOL (args[1]),
-				func_data);
-}
-
 static void
 gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 {
@@ -201,7 +140,7 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[PRE_SYNC] =
 		gtk_signal_new ("pre_sync",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, pre_sync),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -209,7 +148,7 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[POST_SYNC] =
 		gtk_signal_new ("post_sync",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, pre_sync),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -218,16 +157,16 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[SET_PILOT_ID] =
 		gtk_signal_new ("set_pilot_id",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, set_pilot_id),
-				gtk_marshal_INT__POINTER_INT,
+				gp_marshal_INT__POINTER_INT,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
 
 
 	pilot_conduit_sync_abs_signals[SET_STATUS_CLEARED] =
 		gtk_signal_new ("set_status_cleared",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, set_status_cleared),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -235,7 +174,7 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[FOR_EACH] =
 		gtk_signal_new ("for_each",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, for_each),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -243,7 +182,7 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[FOR_EACH_MODIFIED] =
 		gtk_signal_new ("for_each_modified",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, for_each_modified),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -251,15 +190,15 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[COMPARE] =
 		gtk_signal_new ("compare",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, compare),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[ADD_RECORD] =
 		gtk_signal_new ("add_record",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, add_record),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -267,15 +206,15 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[REPLACE_RECORD] =
 		gtk_signal_new ("replace_record",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, replace_record),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[DELETE_RECORD] =
 		gtk_signal_new ("delete_record",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, delete_record),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -283,23 +222,23 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[ARCHIVE_RECORD] =
 		gtk_signal_new ("archive_record",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, archive_record),
-				gtk_marshal_INT__POINTER_BOOL,
+				gp_marshal_INT__POINTER_BOOL,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_BOOL);
 
 	pilot_conduit_sync_abs_signals[MATCH] =
 		gtk_signal_new ("match",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, match),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[FREE_MATCH] =
 		gtk_signal_new ("free_match",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, free_match),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -307,13 +246,11 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	pilot_conduit_sync_abs_signals[PREPARE] =
 		gtk_signal_new ("prepare",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, prepare),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
-	gtk_object_class_add_signals (object_class, pilot_conduit_sync_abs_signals, LAST_SIGNAL);
-
 	conduit_standard_class->copy_to_pilot = gnome_pilot_conduit_standard_real_copy_to_pilot;
 	conduit_standard_class->copy_from_pilot = gnome_pilot_conduit_standard_real_copy_from_pilot;
 	conduit_standard_class->merge_to_pilot = gnome_pilot_conduit_standard_real_merge_to_pilot;
@@ -827,6 +764,8 @@ gnome_pilot_conduit_sync_abs_compare (SyncHandler *sh, PilotRecord *pr, DesktopR
 			 pilot_conduit_sync_abs_signals [COMPARE],
 			 gdr, gpr, &retval);
 
+	g_free (gpr);
+	
 	return retval;
 }
 
@@ -970,7 +909,8 @@ gnome_pilot_conduit_sync_abs_prepare (SyncHandler *sh, DesktopRecord *dr, PilotR
 			 gdr, gpr, &retval);
 
 	*pr = sync_abs_gpr_to_pr (gpr);
-
+	g_free (gpr);
+	
 	return retval;
 }
 
